==> gorilla-notes-0.4.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_grid_layout$build$GridItem.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_grid_layout$build$GridItem=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}
function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,
key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,
descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _possibleConstructorReturn(self,call){return!call||"object"!==_typeof(call)&&"function"!==typeof call?_assertThisInitialized(self):call}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};
return _getPrototypeOf(o$jscomp$0)}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,
superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports.default=void 0;var _react=_interopRequireDefault(require("module$node_modules$react$index")),_reactDom=
_interopRequireDefault(require("module$node_modules$react_dom$index"));global=_interopRequireDefault(require("module$node_modules$prop_types$index"));var _reactDraggable=require("module$node_modules$react_draggable$build$cjs$cjs"),_reactResizable=require("module$node_modules$react_resizable$index"),_utils=require("module$node_modules$react_grid_layout$build$utils"),_calculateUtils=require("module$node_modules$react_grid_layout$build$calculateUtils"),_classnames=_interopRequireDefault(require("module$node_modules$classnames$index"));
require=function(_React$Component){function GridItem(){var _getPrototypeOf2;if(!(this instanceof GridItem))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_possibleConstructorReturn(this,(_getPrototypeOf2=_getPrototypeOf(GridItem)).call.apply(_getPrototypeOf2,[this].concat(args)));_defineProperty(_assertThisInitialized(_this),"state",{resizing:null,dragging:null,className:""});_defineProperty(_assertThisInitialized(_this),
"currentNode",void 0);_defineProperty(_assertThisInitialized(_this),"onDragStart",function(e,_ref){_ref=_ref.node;if(_this.props.onDragStart){var newPosition={top:0,left:0},offsetParent=_ref.offsetParent;if(offsetParent){var parentRect=offsetParent.getBoundingClientRect(),clientRect=_ref.getBoundingClientRect(),cTop=clientRect.top/_this.props.transformScale,pTop=parentRect.top/_this.props.transformScale;newPosition.left=clientRect.left/_this.props.transformScale-parentRect.left/_this.props.transformScale+
offsetParent.scrollLeft;newPosition.top=cTop-pTop+offsetParent.scrollTop;_this.setState({dragging:newPosition});parentRect=(0,_calculateUtils.calcXY)(_this.getPositionParams(),newPosition.top,newPosition.left,_this.props.w,_this.props.h);offsetParent=parentRect.x;parentRect=parentRect.y;return _this.props.onDragStart&&_this.props.onDragStart.call(_assertThisInitialized(_this),_this.props.i,offsetParent,parentRect,{e,node:_ref,newPosition})}}});_defineProperty(_assertThisInitialized(_this),"onDrag",
function(e,_ref2){var node=_ref2.node,deltaX=_ref2.deltaX,deltaY=_ref2.deltaY,_this$props=_this.props;_ref2=_this$props.onDrag;var transformScale=_this$props.transformScale;if(_ref2){_this$props={top:0,left:0};if(!_this.state.dragging)throw Error("onDrag called before onDragStart.");_this$props.left=_this.state.dragging.left+deltaX/transformScale;_this$props.top=_this.state.dragging.top+deltaY/transformScale;_this.setState({dragging:_this$props});deltaY=(0,_calculateUtils.calcXY)(_this.getPositionParams(),
_this$props.top,_this$props.left,_this.props.w,_this.props.h);deltaX=deltaY.x;deltaY=deltaY.y;return _ref2&&_ref2.call(_assertThisInitialized(_this),_this.props.i,deltaX,deltaY,{e,node,newPosition:_this$props})}});_defineProperty(_assertThisInitialized(_this),"onDragStop",function(e,_ref3){_ref3=_ref3.node;if(_this.props.onDragStop){var newPosition={top:0,left:0};if(!_this.state.dragging)throw Error("onDragEnd called before onDragStart.");newPosition.left=_this.state.dragging.left;newPosition.top=
_this.state.dragging.top;_this.setState({dragging:null});var _calcXY3=(0,_calculateUtils.calcXY)(_this.getPositionParams(),newPosition.top,newPosition.left,_this.props.w,_this.props.h),x=_calcXY3.x;_calcXY3=_calcXY3.y;return _this.props.onDragStop&&_this.props.onDragStop.call(_assertThisInitialized(_this),_this.props.i,x,_calcXY3,{e,node:_ref3,newPosition})}});_defineProperty(_assertThisInitialized(_this),"onResizeStop",function(e,callbackData){_this.onResizeHandler(e,callbackData,"onResizeStop")});
_defineProperty(_assertThisInitialized(_this),"onResizeStart",function(e,callbackData){_this.onResizeHandler(e,callbackData,"onResizeStart")});_defineProperty(_assertThisInitialized(_this),"onResize",function(e,callbackData){_this.onResizeHandler(e,callbackData,"onResize")});return _this}_inherits(GridItem,_React$Component);_createClass(GridItem,[{key:"shouldComponentUpdate",value:function(nextProps,nextState){if(this.props.children!==nextProps.children||this.props.droppingPosition!==nextProps.droppingPosition)return!0;
var oldPosition=(0,_calculateUtils.calcGridItemPosition)(this.getPositionParams(this.props),this.props.x,this.props.y,this.props.w,this.props.h,this.state);nextState=(0,_calculateUtils.calcGridItemPosition)(this.getPositionParams(nextProps),nextProps.x,nextProps.y,nextProps.w,nextProps.h,nextState);return!(0,_utils.fastPositionEqual)(oldPosition,nextState)||this.props.useCSSTransforms!==nextProps.useCSSTransforms}},{key:"componentDidMount",value:function(){this.moveDroppingItem({})}},{key:"componentDidUpdate",
value:function(prevProps){this.moveDroppingItem(prevProps)}},{key:"moveDroppingItem",value:function(prevProps){var droppingPosition=this.props.droppingPosition;if(droppingPosition){var prevDroppingPosition=prevProps.droppingPosition||{left:0,top:0};prevProps=this.state.dragging;this.currentNode||(this.currentNode=_reactDom.default.findDOMNode(this));prevDroppingPosition=prevProps&&droppingPosition.left!==prevDroppingPosition.left||droppingPosition.top!==prevDroppingPosition.top;if(!prevProps)this.onDragStart(droppingPosition.e,
{node:this.currentNode,deltaX:droppingPosition.left,deltaY:droppingPosition.top});else if(prevDroppingPosition)this.onDrag(droppingPosition.e,{node:this.currentNode,deltaX:droppingPosition.left-prevProps.left,deltaY:droppingPosition.top-prevProps.top})}}},{key:"getPositionParams",value:function(){var props=0<arguments.length&&void 0!==arguments[0]?arguments[0]:this.props;return{cols:props.cols,containerPadding:props.containerPadding,containerWidth:props.containerWidth,margin:props.margin,maxRows:props.maxRows,
rowHeight:props.rowHeight}}},{key:"createStyle",value:function(pos){var _this$props2=this.props,usePercentages=_this$props2.usePercentages,containerWidth=_this$props2.containerWidth;_this$props2.useCSSTransforms?_this$props2=(0,_utils.setTransform)(pos):(_this$props2=(0,_utils.setTopLeft)(pos),usePercentages&&(_this$props2.left=(0,_utils.perc)(pos.left/containerWidth),_this$props2.width=(0,_utils.perc)(pos.width/containerWidth)));return _this$props2}},{key:"mixinDraggable",value:function(child,isDraggable){return _react.default.createElement(_reactDraggable.DraggableCore,
{disabled:!isDraggable,onStart:this.onDragStart,onDrag:this.onDrag,onStop:this.onDragStop,handle:this.props.handle,cancel:".react-resizable-handle"+(this.props.cancel?","+this.props.cancel:""),scale:this.props.transformScale},child)}},{key:"mixinResizable",value:function(child,position,isResizable){var _this$props3=this.props,cols=_this$props3.cols,x=_this$props3.x,minW=_this$props3.minW,minH=_this$props3.minH,maxW=_this$props3.maxW,maxH=_this$props3.maxH;_this$props3=_this$props3.transformScale;
var positionParams=this.getPositionParams();cols=(0,_calculateUtils.calcGridItemPosition)(positionParams,0,0,cols-x,0).width;minW=(0,_calculateUtils.calcGridItemPosition)(positionParams,0,0,minW,minH);maxW=(0,_calculateUtils.calcGridItemPosition)(positionParams,0,0,maxW,maxH);return _react.default.createElement(_reactResizable.Resizable,{draggableOpts:{disabled:!isResizable},className:isResizable?void 0:"react-resizable-hide",width:position.width,height:position.height,minConstraints:[minW.width,
minW.height],maxConstraints:[Math.min(maxW.width,cols),Math.min(maxW.height,Infinity)],onResizeStop:this.onResizeStop,onResizeStart:this.onResizeStart,onResize:this.onResize,transformScale:_this$props3},child)}},{key:"onResizeHandler",value:function(e,_ref4,handlerName){var node=_ref4.node;_ref4=_ref4.size;var handler=this.props[handlerName];if(handler){var _this$props4=this.props,cols=_this$props4.cols,x=_this$props4.x,y=_this$props4.y,i=_this$props4.i,maxW=_this$props4.maxW,minW=_this$props4.minW,
maxH=_this$props4.maxH;_this$props4=_this$props4.minH;var _calcWH=(0,_calculateUtils.calcWH)(this.getPositionParams(),_ref4.width,_ref4.height,x,y);y=_calcWH.w;_calcWH=_calcWH.h;y=Math.min(y,cols-x);y=Math.max(y,1);y=Math.max(Math.min(y,maxW),minW);_calcWH=Math.max(Math.min(_calcWH,maxH),_this$props4);this.setState({resizing:"onResizeStop"===handlerName?null:_ref4});handler.call(this,i,y,_calcWH,{e,node,size:_ref4})}}},{key:"render",value:function(){var _this$props5=this.props,x=_this$props5.x,y=
_this$props5.y,w=_this$props5.w,h=_this$props5.h,isDraggable=_this$props5.isDraggable,isResizable=_this$props5.isResizable,droppingPosition=_this$props5.droppingPosition;_this$props5=_this$props5.useCSSTransforms;x=(0,_calculateUtils.calcGridItemPosition)(this.getPositionParams(),x,y,w,h,this.state);y=_react.default.Children.only(this.props.children);droppingPosition=_react.default.cloneElement(y,{className:(0,_classnames.default)("react-grid-item",y.props.className,this.props.className,{static:this.props.static,
resizing:!!this.state.resizing,"react-draggable":isDraggable,"react-draggable-dragging":!!this.state.dragging,dropping:!!droppingPosition,cssTransforms:_this$props5}),style:_objectSpread({},this.props.style,{},y.props.style,{},this.createStyle(x))});droppingPosition=this.mixinResizable(droppingPosition,x,isResizable);return droppingPosition=this.mixinDraggable(droppingPosition,isDraggable)}}]);return GridItem}(_react.default.Component);exports.default=require;_defineProperty(require,"propTypes",{children:global.default.element,
cols:global.default.number.isRequired,containerWidth:global.default.number.isRequired,rowHeight:global.default.number.isRequired,margin:global.default.array.isRequired,maxRows:global.default.number.isRequired,containerPadding:global.default.array.isRequired,x:global.default.number.isRequired,y:global.default.number.isRequired,w:global.default.number.isRequired,h:global.default.number.isRequired,minW:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("minWidth not Number");
if(propName>props.w||propName>props.maxW)return Error("minWidth larger than item width/maxWidth")},maxW:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("maxWidth not Number");if(propName<props.w||propName<props.minW)return Error("maxWidth smaller than item width/minWidth")},minH:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("minHeight not Number");if(propName>props.h||propName>props.maxH)return Error("minHeight larger than item height/maxHeight")},
maxH:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("maxHeight not Number");if(propName<props.h||propName<props.minH)return Error("maxHeight smaller than item height/minHeight")},i:global.default.string.isRequired,onDragStop:global.default.func,onDragStart:global.default.func,onDrag:global.default.func,onResizeStop:global.default.func,onResizeStart:global.default.func,onResize:global.default.func,isDraggable:global.default.bool.isRequired,isResizable:global.default.bool.isRequired,
static:global.default.bool,useCSSTransforms:global.default.bool.isRequired,transformScale:global.default.number,className:global.default.string,handle:global.default.string,cancel:global.default.string,droppingPosition:global.default.shape({e:global.default.object.isRequired,left:global.default.number.isRequired,top:global.default.number.isRequired})});_defineProperty(require,"defaultProps",{className:"",cancel:"",handle:"",minH:1,minW:1,maxH:Infinity,maxW:Infinity,transformScale:1})}
//# sourceMappingURL=module$node_modules$react_grid_layout$build$GridItem.js.map

==> gorilla-notes-0.5.7.jar: public/js/compiled/cljs-runtime/module$node_modules$react_grid_layout$build$GridItem.js <==
shadow$provide.module$node_modules$react_grid_layout$build$GridItem=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}
function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,
key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,
descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _possibleConstructorReturn(self,call){return!call||"object"!==_typeof(call)&&"function"!==typeof call?_assertThisInitialized(self):call}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};
return _getPrototypeOf(o$jscomp$0)}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,
superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports.default=void 0;var _react=_interopRequireDefault(require("module$node_modules$react$index")),
_reactDom=_interopRequireDefault(require("module$node_modules$react_dom$index"));global=_interopRequireDefault(require("module$node_modules$prop_types$index"));var _reactDraggable=require("module$node_modules$react_draggable$build$cjs$cjs"),_reactResizable=require("module$node_modules$react_resizable$index"),_utils=require("module$node_modules$react_grid_layout$build$utils"),_calculateUtils=require("module$node_modules$react_grid_layout$build$calculateUtils"),_classnames=_interopRequireDefault(require("module$node_modules$classnames$index"));
require=function(_React$Component){function GridItem(){var _getPrototypeOf2;if(!(this instanceof GridItem))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_possibleConstructorReturn(this,(_getPrototypeOf2=_getPrototypeOf(GridItem)).call.apply(_getPrototypeOf2,[this].concat(args)));_defineProperty(_assertThisInitialized(_this),"state",{resizing:null,dragging:null,className:""});_defineProperty(_assertThisInitialized(_this),
"currentNode",void 0);_defineProperty(_assertThisInitialized(_this),"onDragStart",function(e,_ref){_ref=_ref.node;if(_this.props.onDragStart){var newPosition={top:0,left:0},offsetParent=_ref.offsetParent;if(offsetParent){var parentRect=offsetParent.getBoundingClientRect(),clientRect=_ref.getBoundingClientRect(),cTop=clientRect.top/_this.props.transformScale,pTop=parentRect.top/_this.props.transformScale;newPosition.left=clientRect.left/_this.props.transformScale-parentRect.left/_this.props.transformScale+
offsetParent.scrollLeft;newPosition.top=cTop-pTop+offsetParent.scrollTop;_this.setState({dragging:newPosition});parentRect=(0,_calculateUtils.calcXY)(_this.getPositionParams(),newPosition.top,newPosition.left,_this.props.w,_this.props.h);offsetParent=parentRect.x;parentRect=parentRect.y;return _this.props.onDragStart&&_this.props.onDragStart.call(_assertThisInitialized(_this),_this.props.i,offsetParent,parentRect,{e:e,node:_ref,newPosition:newPosition})}}});_defineProperty(_assertThisInitialized(_this),
"onDrag",function(e,_ref2){var node=_ref2.node,deltaX=_ref2.deltaX,deltaY=_ref2.deltaY,_this$props=_this.props;_ref2=_this$props.onDrag;var transformScale=_this$props.transformScale;if(_ref2){_this$props={top:0,left:0};if(!_this.state.dragging)throw Error("onDrag called before onDragStart.");_this$props.left=_this.state.dragging.left+deltaX/transformScale;_this$props.top=_this.state.dragging.top+deltaY/transformScale;_this.setState({dragging:_this$props});deltaY=(0,_calculateUtils.calcXY)(_this.getPositionParams(),
_this$props.top,_this$props.left,_this.props.w,_this.props.h);deltaX=deltaY.x;deltaY=deltaY.y;return _ref2&&_ref2.call(_assertThisInitialized(_this),_this.props.i,deltaX,deltaY,{e:e,node:node,newPosition:_this$props})}});_defineProperty(_assertThisInitialized(_this),"onDragStop",function(e,_ref3){_ref3=_ref3.node;if(_this.props.onDragStop){var newPosition={top:0,left:0};if(!_this.state.dragging)throw Error("onDragEnd called before onDragStart.");newPosition.left=_this.state.dragging.left;newPosition.top=
_this.state.dragging.top;_this.setState({dragging:null});var _calcXY3=(0,_calculateUtils.calcXY)(_this.getPositionParams(),newPosition.top,newPosition.left,_this.props.w,_this.props.h),x=_calcXY3.x;_calcXY3=_calcXY3.y;return _this.props.onDragStop&&_this.props.onDragStop.call(_assertThisInitialized(_this),_this.props.i,x,_calcXY3,{e:e,node:_ref3,newPosition:newPosition})}});_defineProperty(_assertThisInitialized(_this),"onResizeStop",function(e,callbackData){_this.onResizeHandler(e,callbackData,"onResizeStop")});
_defineProperty(_assertThisInitialized(_this),"onResizeStart",function(e,callbackData){_this.onResizeHandler(e,callbackData,"onResizeStart")});_defineProperty(_assertThisInitialized(_this),"onResize",function(e,callbackData){_this.onResizeHandler(e,callbackData,"onResize")});return _this}_inherits(GridItem,_React$Component);_createClass(GridItem,[{key:"shouldComponentUpdate",value:function(nextProps,nextState){if(this.props.children!==nextProps.children||this.props.droppingPosition!==nextProps.droppingPosition)return!0;
var oldPosition=(0,_calculateUtils.calcGridItemPosition)(this.getPositionParams(this.props),this.props.x,this.props.y,this.props.w,this.props.h,this.state);nextState=(0,_calculateUtils.calcGridItemPosition)(this.getPositionParams(nextProps),nextProps.x,nextProps.y,nextProps.w,nextProps.h,nextState);return!(0,_utils.fastPositionEqual)(oldPosition,nextState)||this.props.useCSSTransforms!==nextProps.useCSSTransforms}},{key:"componentDidMount",value:function(){this.moveDroppingItem({})}},{key:"componentDidUpdate",
value:function(prevProps){this.moveDroppingItem(prevProps)}},{key:"moveDroppingItem",value:function(prevProps){var droppingPosition=this.props.droppingPosition;if(droppingPosition){var prevDroppingPosition=prevProps.droppingPosition||{left:0,top:0};prevProps=this.state.dragging;this.currentNode||(this.currentNode=_reactDom.default.findDOMNode(this));prevDroppingPosition=prevProps&&droppingPosition.left!==prevDroppingPosition.left||droppingPosition.top!==prevDroppingPosition.top;if(!prevProps)this.onDragStart(droppingPosition.e,
{node:this.currentNode,deltaX:droppingPosition.left,deltaY:droppingPosition.top});else if(prevDroppingPosition)this.onDrag(droppingPosition.e,{node:this.currentNode,deltaX:droppingPosition.left-prevProps.left,deltaY:droppingPosition.top-prevProps.top})}}},{key:"getPositionParams",value:function(){var props=0<arguments.length&&void 0!==arguments[0]?arguments[0]:this.props;return{cols:props.cols,containerPadding:props.containerPadding,containerWidth:props.containerWidth,margin:props.margin,maxRows:props.maxRows,
rowHeight:props.rowHeight}}},{key:"createStyle",value:function(pos){var _this$props2=this.props,usePercentages=_this$props2.usePercentages,containerWidth=_this$props2.containerWidth;_this$props2.useCSSTransforms?_this$props2=(0,_utils.setTransform)(pos):(_this$props2=(0,_utils.setTopLeft)(pos),usePercentages&&(_this$props2.left=(0,_utils.perc)(pos.left/containerWidth),_this$props2.width=(0,_utils.perc)(pos.width/containerWidth)));return _this$props2}},{key:"mixinDraggable",value:function(child,isDraggable){return _react.default.createElement(_reactDraggable.DraggableCore,
{disabled:!isDraggable,onStart:this.onDragStart,onDrag:this.onDrag,onStop:this.onDragStop,handle:this.props.handle,cancel:".react-resizable-handle"+(this.props.cancel?","+this.props.cancel:""),scale:this.props.transformScale},child)}},{key:"mixinResizable",value:function(child,position,isResizable){var _this$props3=this.props,cols=_this$props3.cols,x=_this$props3.x,minW=_this$props3.minW,minH=_this$props3.minH,maxW=_this$props3.maxW,maxH=_this$props3.maxH;_this$props3=_this$props3.transformScale;
var positionParams=this.getPositionParams();cols=(0,_calculateUtils.calcGridItemPosition)(positionParams,0,0,cols-x,0).width;minW=(0,_calculateUtils.calcGridItemPosition)(positionParams,0,0,minW,minH);maxW=(0,_calculateUtils.calcGridItemPosition)(positionParams,0,0,maxW,maxH);return _react.default.createElement(_reactResizable.Resizable,{draggableOpts:{disabled:!isResizable},className:isResizable?void 0:"react-resizable-hide",width:position.width,height:position.height,minConstraints:[minW.width,
minW.height],maxConstraints:[Math.min(maxW.width,cols),Math.min(maxW.height,Infinity)],onResizeStop:this.onResizeStop,onResizeStart:this.onResizeStart,onResize:this.onResize,transformScale:_this$props3},child)}},{key:"onResizeHandler",value:function(e,_ref4,handlerName){var node=_ref4.node;_ref4=_ref4.size;var handler=this.props[handlerName];if(handler){var _this$props4=this.props,cols=_this$props4.cols,x=_this$props4.x,y=_this$props4.y,i=_this$props4.i,maxW=_this$props4.maxW,minW=_this$props4.minW,
maxH=_this$props4.maxH;_this$props4=_this$props4.minH;var _calcWH=(0,_calculateUtils.calcWH)(this.getPositionParams(),_ref4.width,_ref4.height,x,y);y=_calcWH.w;_calcWH=_calcWH.h;y=Math.min(y,cols-x);y=Math.max(y,1);y=Math.max(Math.min(y,maxW),minW);_calcWH=Math.max(Math.min(_calcWH,maxH),_this$props4);this.setState({resizing:"onResizeStop"===handlerName?null:_ref4});handler.call(this,i,y,_calcWH,{e:e,node:node,size:_ref4})}}},{key:"render",value:function(){var _this$props5=this.props,x=_this$props5.x,
y=_this$props5.y,w=_this$props5.w,h=_this$props5.h,isDraggable=_this$props5.isDraggable,isResizable=_this$props5.isResizable,droppingPosition=_this$props5.droppingPosition;_this$props5=_this$props5.useCSSTransforms;x=(0,_calculateUtils.calcGridItemPosition)(this.getPositionParams(),x,y,w,h,this.state);y=_react.default.Children.only(this.props.children);droppingPosition=_react.default.cloneElement(y,{className:(0,_classnames.default)("react-grid-item",y.props.className,this.props.className,{static:this.props.static,
resizing:!!this.state.resizing,"react-draggable":isDraggable,"react-draggable-dragging":!!this.state.dragging,dropping:!!droppingPosition,cssTransforms:_this$props5}),style:_objectSpread({},this.props.style,{},y.props.style,{},this.createStyle(x))});droppingPosition=this.mixinResizable(droppingPosition,x,isResizable);return droppingPosition=this.mixinDraggable(droppingPosition,isDraggable)}}]);return GridItem}(_react.default.Component);exports.default=require;_defineProperty(require,"propTypes",{children:global.default.element,
cols:global.default.number.isRequired,containerWidth:global.default.number.isRequired,rowHeight:global.default.number.isRequired,margin:global.default.array.isRequired,maxRows:global.default.number.isRequired,containerPadding:global.default.array.isRequired,x:global.default.number.isRequired,y:global.default.number.isRequired,w:global.default.number.isRequired,h:global.default.number.isRequired,minW:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("minWidth not Number");
if(propName>props.w||propName>props.maxW)return Error("minWidth larger than item width/maxWidth")},maxW:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("maxWidth not Number");if(propName<props.w||propName<props.minW)return Error("maxWidth smaller than item width/minWidth")},minH:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("minHeight not Number");if(propName>props.h||propName>props.maxH)return Error("minHeight larger than item height/maxHeight")},
maxH:function(props,propName){propName=props[propName];if("number"!==typeof propName)return Error("maxHeight not Number");if(propName<props.h||propName<props.minH)return Error("maxHeight smaller than item height/minHeight")},i:global.default.string.isRequired,onDragStop:global.default.func,onDragStart:global.default.func,onDrag:global.default.func,onResizeStop:global.default.func,onResizeStart:global.default.func,onResize:global.default.func,isDraggable:global.default.bool.isRequired,isResizable:global.default.bool.isRequired,
static:global.default.bool,useCSSTransforms:global.default.bool.isRequired,transformScale:global.default.number,className:global.default.string,handle:global.default.string,cancel:global.default.string,droppingPosition:global.default.shape({e:global.default.object.isRequired,left:global.default.number.isRequired,top:global.default.number.isRequired})});_defineProperty(require,"defaultProps",{className:"",cancel:"",handle:"",minH:1,minW:1,maxH:Infinity,maxW:Infinity,transformScale:1})}
//# sourceMappingURL=module$node_modules$react_grid_layout$build$GridItem.js.map
